/*
 * Copyright (C) 2012 Michael Olbrich <m.olbrich@pengutonix.de>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * version 2 as published by the Free Software Foundation
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 * MA  02110-1301, USA.
 */

#ifndef MO_APP_H
#define MO_APP_H

#include <QtCore/QObject>
#include <QtCore/QMap>

class MoAppList;

class MoApp : public QObject
{
	Q_OBJECT
	Q_PROPERTY(QString name READ name NOTIFY nameChanged)
	Q_PROPERTY(QString icon READ icon NOTIFY iconChanged)
	Q_PROPERTY(QString fileName READ fileName NOTIFY fileNameChanged)
	Q_PROPERTY(QString element READ element NOTIFY elementChanged)
	Q_PROPERTY(QString module READ module NOTIFY moduleChanged)
	Q_PROPERTY(QString menu READ menu NOTIFY menuChanged)
	Q_PROPERTY(QString localeAware READ localeAware NOTIFY localeAwareChanged)

public:
	MoApp(QObject *parent = 0);
	~MoApp();

	QString name() const;
	QString icon() const;
	QString fileName() const;
	QString element() const;
	QString module() const;
	QString menu() const;
	QString localeAware() const;

	QString get(const QString &type) const;
	bool contains(const QString &type) const;
	void clear();

public slots:
	void update(const QString &type, const QString &value);

signals:
	void nameChanged(const QString &name);
	void iconChanged(const QString &icon);
	void fileNameChanged(const QString &fileName);
	void elementChanged(const QString &element);
	void moduleChanged(const QString &module);
	void menuChanged(const QString &module);
	void localeAwareChanged(const QString &module);

private:
	QMap<QString, QString> m_data;
};

#endif // MO_APP_H

