/*
 * Copyright (C) 2012 Michael Olbrich <m.olbrich@pengutonix.de>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * version 2 as published by the Free Software Foundation
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 * MA  02110-1301, USA.
 */

import QtQuick 1.0

QtObject {
	id: cache
	property ListModel list : ListModel {}

	function createComponent(app) {
		var component
		if (app.fileName) {
			component = Qt.createComponent(app.fileName)
		}
		else if (app.module && app.element) {
			component = Qt.createQmlObject(
				'import QtQuick 1.0; import ' + app.module +
				'; Component { ' + app.element + '{}}', cache)
		}
		return component
	}

	function get(name, app, locale) {
		var obj;
		for (var i = 0; i < list.count; ++i) {
			var e = list.get(i)
			if (e.name == name) {
				if ((app.localeAware != "yes") && (e.locale != locale))
					__remove(i)
				else
					obj = e.obj
				break
			}
		}
		if (!obj) {
			var component = createComponent(app)
			if (component.status == Component.Ready)
				obj = _create(component)
			if (obj)
				list.append({
					"name": name,
					"obj": obj,
					"locale": locale,
					"component": component });
			else
				console.log("Failed to load " + name +
					" (" + app.fileName + ")")
		}
		return obj;
	}
	function remove(item) {
		for (var i = 0; i < list.count; ++i) {
			var e = list.get(i)
			if ((e.name == item) || (e.obj == item)) {
				__remove(i)
				break
			}
		}
	}

	/* protected */
	function _create(component) {
		return component.createObject(undefined)
	}

	/* private */
	function __remove(index) {
		var e = list.get(index)
		e.obj.destroy()
		e.component.destroy()
		list.remove(index)
	}
}

